
define romaa position
(
  # specify the size of the model
  size [0.570 0.520 0.200]

  # specify the position of the object center, relative to its pose
  # the robot center of rotation is offset from its center of area
  origin [-0.111 0.0 0]

  # draw a nose on the robot so we can see which way it points
  # (positive X axis)
  gui_nose 1
  # if 1, draw a bounding box around the model indicating its size
  gui_boundary 1
  
  # estimated mass in KG
  mass 35

  # this polygon approximates the shape of a pioneer
  blocks 1
  block[0].points 12

  block[0].point[0] [ 0.174 0.142 ]
  block[0].point[1] [ 0.0962 0.260 ]
  block[0].point[2] [ 0.000 0.260 ]
  block[0].point[3] [ -0.136 0.260 ]
  block[0].point[4] [ -0.344 0.221 ]
  block[0].point[5] [ -0.396 0.109 ]

  block[0].point[6] [ -0.396 -0.109 ]
  block[0].point[7] [ -0.344 -0.221 ]
  block[0].point[8] [ -0.136 -0.260 ]
  block[0].point[9] [ 0.000 -0.260 ]
  block[0].point[10] [ 0.0962 -0.260 ]
  block[0].point[11] [ 0.174 -0.142 ]

  # differential-steer model
  drive "diff"

  color "blue"
)

